# CLI

This project uses [Typer](https://typer.tiangolo.com/) and [Click](https://click.palletsprojects.com/) for CLI functionality. When the project is installed the cli is available at `aircheck_test_model`.

The full help contents can be visited with the help flag.

```bash
aircheck_test_model --help
```

The CLI itself is defined at `aircheck_test_model.cli`. New commands can be added there.
